/* $XConsortium: xbiff.c,v 1.19 94/04/17 20:43:28 rws Exp $ */
/*
Copyright (c) 1988  X Consortium

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of the X Consortium shall
not be used in advertising or otherwise to promote the sale, use or
other dealings in this Software without prior written authorization
from the X Consortium.

 */

#include <stdio.h>
#include <X11/Xatom.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include "SSMailbox.h"
#include <X11/Xaw/Cardinals.h>

#ifdef AAPI
#include <audio/Alib.h>
#include <audio/Play.h>
#endif

extern void exit();
static void quit();

char *ProgramName;

#ifdef AAPI
Widget playWidget;
#endif

static XrmOptionDescRec options[] = {
{ "-update", "*ssmailbox.update",      XrmoptionSepArg, (XtPointer )NULL },
{ "-file",   "*ssmailbox.file",        XrmoptionSepArg, (XtPointer )NULL },
{ "-volume", "*ssmailbox.volume",      XrmoptionSepArg, (XtPointer )NULL },
{ "-shape",  "*ssmailbox.shapeWindow", XrmoptionNoArg,  (XtPointer )"on" },
{ "-soundBindings",   "*ssmailbox.soundBindings", XrmoptionSepArg, (XtPointer )NULL },
{ "-sound",  "*ssmailbox.sound",       XrmoptionSepArg, (XtPointer )NULL },
{ "-noMailSound",  "*ssmailbox.noMailSound",       XrmoptionSepArg, (XtPointer )NULL },
{ "-faceBindings",    "*ssmailbox.faceBindings",  XrmoptionSepArg, (XtPointer )NULL },
{ "-face",   "*ssmailbox.face",        XrmoptionSepArg, (XtPointer )NULL },
{ "-autoResize",      "*ssmailbox.autoResize",    XrmoptionNoArg, (XtPointer )"on"  },
{ "-noAutoResize",    "*ssmailbox.autoResize",    XrmoptionNoArg, (XtPointer )"off" },
{ "-caseSensitive",   "*ssmailbox.caseSensitive", XrmoptionNoArg, (XtPointer )"on"  },
{ "-noCaseSensitive", "*ssmailbox.caseSensitive", XrmoptionNoArg, (XtPointer )"off" },
{ "-caseInsensitive", "*ssmailbox.caseSensitive", XrmoptionNoArg, (XtPointer )"off" },
{ "-debug",           "*ssmailbox.debug",         XrmoptionNoArg, (XtPointer )"on"  },
{ "-soundPath",       "*ssmailbox.soundPath",     XrmoptionSepArg, (XtPointer )NULL  }
};

static XtActionsRec xbiff_actions[] = {
    { "quit", quit },
};
static Atom wm_delete_window;

static void Usage ()
{
    static char *help_message[] = {
"where options include:",
"    -display host:dpy    X server to contact",
"    -geometry geom       size of mailbox",
"    -bg color            background color",
"    -fg color            foreground color",
"    -rv                  reverse video",
/* Our options start here */
"    -update seconds      how often to check for mail",
"    -file file           file to watch",
"    -volume percentage   how loud to ring the bell or play a sound",
"    -shape               shape the window",
"    -soundBindings       bindings of sounds to message header patterns",
"    -sound               default sound to play for new mail",
"    -noMailSound         sound to play when there's no new mail",
"    -faceBindings        bindings of bitmaps to message header patterns",
"    -face                default bitmap to display for new mail",
"    -autoResize          resize the window to match bitmap size",
"    -noAutoResize        keep window at constant size",
"    -noCaseSensitive     downshift uppercase characters in header lines",
"    -caseInsensitive     same as '-noCaseSensitive'",
"    -caseSensitive       don't change uppercase characters in header lines",
"    -debug               print trace to help find binding problems",
"    -soundPath           list of directories where sound files live",
NULL};
    char **cpp;

    fprintf (stderr, "usage:  %s [-options ...]\n", ProgramName);
    for (cpp = help_message; *cpp; cpp++) {
	fprintf (stderr, "%s\n", *cpp);
    }
    fprintf (stderr, "\n");
    exit (1);
}


void main (argc, argv)
    int argc;
    char **argv;
{
    XtAppContext xtcontext;
    Widget toplevel, w;

    ProgramName = argv[0];

    toplevel = XtAppInitialize (&xtcontext, "XBiff++", options, XtNumber (options),
			     &argc, argv, NULL, NULL, 0);
    if (argc != 1) Usage ();

    /*
     * This is a hack so that f.delete will do something useful in this
     * single-window application.
     */
    XtAppAddActions (xtcontext, xbiff_actions, XtNumber(xbiff_actions));
    XtOverrideTranslations(toplevel,
		   XtParseTranslationTable ("<Message>WM_PROTOCOLS: quit()"));

    w = XtCreateManagedWidget ("ssmailbox", ssmailboxWidgetClass, toplevel,
			       NULL, 0);

#ifdef AAPI
{
    Audio *audio;
    long status;
    Arg args[3];
    Cardinal n;

    audio = AOpenAudio(NULL, &status);
    if (audio == NULL)
	playWidget = 0;
    else {

	AtInitialize(audio);

	n = 0;
	XtSetArg(args[n], AuNgain, 100); n++;
	XtSetArg(args[n], AuNaudioConnection, audio); n++;
	XtSetArg(args[n], AuNpriority, AuUrgent); n++;
	playWidget = AuCreatePlay(w, "play", args, n);
    }
}
#endif

    XtRealizeWidget (toplevel);
    wm_delete_window = XInternAtom (XtDisplay(toplevel), "WM_DELETE_WINDOW",
                                    False);
    (void) XSetWMProtocols (XtDisplay(toplevel), XtWindow(toplevel),
                            &wm_delete_window, 1);
    XtAppMainLoop (xtcontext);
}

static void quit (w, event, params, num_params)
    Widget w;
    XEvent *event;
    String *params;
    Cardinal *num_params;
{
    if (event->type == ClientMessage &&
        event->xclient.data.l[0] != wm_delete_window) {
        XBell (XtDisplay(w), 0);
        return;
    }
    XCloseDisplay (XtDisplay(w));
    exit (0);
}
